﻿/*
 * scraep - robust 4chan thread watcher
 * Copyright (C) 2010  ed <tripflag@gmail.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License v2
 * (version 2) as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, refer to the following URL:
 * http://www.gnu.org/licenses/old-licenses/gpl-2.0.txt
 */
using System;
using System.Collections.Generic;
using System.Text;

namespace scraep
{
    class Downloader
    {
        object listlock;
        bool downloading;
        List<Image> images;
        public Downloader()
        {
            listlock = new object();
            images = new List<Image>();
            System.Threading.Thread runner = new System.Threading.Thread(new System.Threading.ThreadStart(core));
            runner.IsBackground = true;
            runner.Start();
        }
        public void add(Image[] image)
        {
            lock (listlock)
            {
                foreach (Image i in image)
                {
                    if (!i.exists())
                    {
                        images.Add(i);
                    }
                }
            }
        }
        void core()
        {
            while (true)
            {
                Image image = null;
                lock (listlock)
                {
                    if (images.Count > 0)
                    {
                        image = images[0];
                        images.RemoveAt(0);
                    }
                }
                if (image != null)
                {
                    downloading = true;
                    if (!image.exists())
                    {
                        if (image.download())
                        {
                            if (!image.verify())
                            {
                                image.delete();
                            }
                        }
                    }
                }
                else
                {
                    downloading = false;
                }
                System.Threading.Thread.Sleep(10);
            }
        }
        public int remain()
        {
            return images.Count + (downloading ? 1 : 0);
        }
    }
}
