﻿/*
 * scraep - robust 4chan thread watcher
 * Copyright (C) 2010  ed <tripflag@gmail.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License v2
 * (version 2) as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, refer to the following URL:
 * http://www.gnu.org/licenses/old-licenses/gpl-2.0.txt
 */
using System;
using System.Collections.Generic;
using System.Text;

namespace scraep
{
    class Image
    {
        public readonly byte[] md5;
        public readonly string url;
        public readonly string path;
        public Image(string url, string path, string md5)
        {
            this.md5 = System.Convert.FromBase64String(md5);
            this.url = url;
            this.path = path;
        }
        public void delete()
        {
            System.IO.File.Delete(path);
        }
        public bool exists()
        {
            return System.IO.File.Exists(path);
        }
        public bool download()
        {
            try
            {
                new System.Net.WebClient().DownloadFile(url, "blob.tmp");
                System.IO.File.Move("blob.tmp", path);
                return true;
            }
            catch { }
            return false;
        }
        public bool verify()
        {
            byte[] sum = { };
            if (!exists()) return false;
            using (System.Security.Cryptography.MD5 summer = new System.Security.Cryptography.MD5CryptoServiceProvider())
            using (System.IO.FileStream fs = new System.IO.FileStream(path, System.IO.FileMode.Open, System.IO.FileAccess.Read))
                sum = summer.ComputeHash(fs);
            return bytecompare(md5, sum);
        }
        bool bytecompare(byte[] a, byte[] b)
        {
            if (a.Length != b.Length)
            {
                return false;
            }
            for (int i = 0; i < a.Length; i++)
            {
                if (a[i] != b[i])
                {
                    return false;
                }
            }
            return true;
        }
    }
}
